@@ -1,32 +1,17 @@
-# Copyright (C) 2013-2014 Red Hat, Inc. All rights reserved.
+# Copyright (C) 2013-2014 Michal Minar <miminar@redhat.com>
 #
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are met:
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
 #
-# 1. Redistributions of source code must retain the above copyright notice,
-#    this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the above copyright notice,
-#    this list of conditions and the following disclaimer in the documentation
-#    and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
-# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
-# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-# POSSIBILITY OF SUCH DAMAGE.
-#
-# The views and conclusions contained in the software and documentation are
-# those of the authors and should not be interpreted as representing official
-# policies, either expressed or implied, of the FreeBSD Project.
-#
-# Authors: Michal Minar <miminar@redhat.com>
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, see <http://www.gnu.org/licenses/>.
 """
 Module with predefined exceptions for use in scripts.
 """
@@ -45,6 +30,16 @@ class LmiFailed(LmiError):
     """
     pass
 
+class LmiUnsatisfiedDependencies(LmiFailed):
+    """
+    Raised when no guarded command in
+    :py:class:`~.command.select.LmiSelectCommand` can be loaded due to
+    unsatisfied requirements.
+    """
+    def __init__(self, uris):
+        LmiFailed.__init__(self, "Profile and class dependencies were not"
+                " satisfied for this session (%s)." % ', '.join(uris))
+
 class LmiUnexpectedResult(LmiError):
     """
     Raised, when command's associated function returns something unexpected.
@@ -113,6 +108,15 @@ class LmiCommandInvalidCallable(LmiCommandInvalidProperty):
     def __init__(self, module_name, class_name, msg):
         LmiCommandInvalidProperty.__init__(self, module_name, class_name, msg)
 
+class LmiBadSelectExpression(LmiCommandError):
+    """
+    Raised, when expression of :py:class:`~.command.select.LmiSelectCommand`
+    could not be evaluated.
+    """
+    def __init__(self, module_name, class_name, expr):
+        LmiCommandError.__init__(self, module_name, class_name,
+                "Bad select expression: %s" % expr)
+
 class LmiTerminate(Exception):
     """
     Raised to cleanly terminate interavtive shell.
